<?php
/**
 * VW Car Rental Theme Customizer
 *
 * @package VW Car Rental
 */

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function vw_car_rental_custom_controls() {

    load_template( trailingslashit( get_template_directory() ) . '/inc/custom-controls.php' );
}
add_action( 'customize_register', 'vw_car_rental_custom_controls' );

function vw_car_rental_customize_register( $wp_customize ) {

	load_template( trailingslashit( get_template_directory() ) . 'inc/content-creation/class-customizer-content-creation.php' );

	//add home page setting pannel
	$wp_customize->add_panel( 'vw_car_rental_panel_id', array(
	    'priority' => 10,
	    'capability' => 'edit_theme_options',
	    'theme_supports' => '',
	    'title' => __( 'VW Settings', 'vw-car-rental' ),
	    'description' => __( 'Description of what this panel does.', 'vw-car-rental' ),
	) );

	$wp_customize->add_section( 'vw_car_rental_left_right', array(
    	'title'      => __( 'General Settings', 'vw-car-rental' ),
		'priority'   => 30,
		'panel' => 'vw_car_rental_panel_id'
	) );

	$wp_customize->add_setting('vw_car_rental_width_option',array(
        'default' => __('Full Width','vw-car-rental'),
        'sanitize_callback' => 'vw_car_rental_sanitize_choices'
	));
	$wp_customize->add_control(new VW_Car_Rental_Image_Radio_Control($wp_customize, 'vw_car_rental_width_option', array(
        'type' => 'select',
        'label' => __('Width Layouts','vw-car-rental'),
        'description' => __('Here you can change the width layout of Website.','vw-car-rental'),
        'section' => 'vw_car_rental_left_right',
        'choices' => array(
            'Full Width' => get_template_directory_uri().'/assets/images/full-width.png',
            'Wide Width' => get_template_directory_uri().'/assets/images/wide-width.png',
            'Boxed' => get_template_directory_uri().'/assets/images/boxed-width.png',
    ))));

	// Add Settings and Controls for Layout
	$wp_customize->add_setting('vw_car_rental_theme_options',array(
        'default' => __('Right Sidebar','vw-car-rental'),
        'sanitize_callback' => 'vw_car_rental_sanitize_choices'	        
	) );
	$wp_customize->add_control('vw_car_rental_theme_options', array(
        'type' => 'select',
        'label' => __('Post Sidebar Layout','vw-car-rental'),
        'description' => __('Here you can change the sidebar layout for posts. ','vw-car-rental'),
        'section' => 'vw_car_rental_left_right',
        'choices' => array(
            'Left Sidebar' => __('Left Sidebar','vw-car-rental'),
            'Right Sidebar' => __('Right Sidebar','vw-car-rental'),
            'One Column' => __('One Column','vw-car-rental'),
            'Three Columns' => __('Three Columns','vw-car-rental'),
            'Four Columns' => __('Four Columns','vw-car-rental'),
            'Grid Layout' => __('Grid Layout','vw-car-rental')
        ),
	));

	$wp_customize->add_setting('vw_car_rental_page_layout',array(
        'default' => __('One Column','vw-car-rental'),
        'sanitize_callback' => 'vw_car_rental_sanitize_choices'
	));
	$wp_customize->add_control('vw_car_rental_page_layout',array(
        'type' => 'select',
        'label' => __('Page Sidebar Layout','vw-car-rental'),
        'description' => __('Here you can change the sidebar layout for pages. ','vw-car-rental'),
        'section' => 'vw_car_rental_left_right',
        'choices' => array(
            'Left Sidebar' => __('Left Sidebar','vw-car-rental'),
            'Right Sidebar' => __('Right Sidebar','vw-car-rental'),
            'One Column' => __('One Column','vw-car-rental')
        ),
	) );

	//Topbar
	$wp_customize->add_section( 'vw_car_rental_topbar', array(
    	'title'      => __( 'Topbar Settings', 'vw-car-rental' ),
		'priority'   => 30,
		'panel' => 'vw_car_rental_panel_id'
	) );

	$wp_customize->add_setting('vw_car_rental_phone',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control('vw_car_rental_phone',array(
		'label'	=> __('Add Phone no.','vw-car-rental'),
		'input_attrs' => array(
            'placeholder' => __( '+00 123 456 7890', 'vw-car-rental' ),
        ),
		'section'=> 'vw_car_rental_topbar',
		'type'=> 'text'
	));

	$wp_customize->add_setting( 'vw_car_rental_search_hide_show',
       array(
          'default' => 1,
          'transport' => 'refresh',
          'sanitize_callback' => 'vw_car_rental_switch_sanitization'
    ));  
    $wp_customize->add_control( new VW_Car_Rental_Toggle_Switch_Custom_Control( $wp_customize, 'vw_car_rental_search_hide_show',
       array(
          'label' => esc_html__( 'Show / Hide Search','vw-car-rental' ),
          'section' => 'vw_car_rental_topbar'
    )));
    
	//Slider
	$wp_customize->add_section( 'vw_car_rental_slidersettings' , array(
    	'title'      => __( 'Slider Section', 'vw-car-rental' ),
		'priority'   => null,
		'panel' => 'vw_car_rental_panel_id'
	) );

	$wp_customize->add_setting( 'vw_car_rental_slider_hide_show',array(
		'transport' => 'refresh',
		'sanitize_callback' => 'vw_car_rental_switch_sanitization'
    ));  
    $wp_customize->add_control( new VW_Car_Rental_Toggle_Switch_Custom_Control( $wp_customize, 'vw_car_rental_slider_hide_show', array(
		'label' => esc_html__( 'Show / Hide Slider','vw-car-rental' ),
		'section' => 'vw_car_rental_slidersettings'
    )));

	for ( $count = 1; $count <= 4; $count++ ) {

		$wp_customize->add_setting( 'vw_car_rental_slider_page' . $count, array(
			'default'           => '',
			'sanitize_callback' => 'vw_car_rental_sanitize_dropdown_pages'
		) );
		$wp_customize->add_control( 'vw_car_rental_slider_page' . $count, array(
			'label'    => __( 'Select Slide Image Page', 'vw-car-rental' ),
			'description' => __('Slider image size (1500 x 590)','vw-car-rental'),
			'section'  => 'vw_car_rental_slidersettings',
			'type'     => 'dropdown-pages'
		) );
	}

	//content layout
	$wp_customize->add_setting('vw_car_rental_slider_content_option',array(
        'default' => __('Left','vw-car-rental'),
        'sanitize_callback' => 'vw_car_rental_sanitize_choices'
	));
	$wp_customize->add_control(new VW_Car_Rental_Image_Radio_Control($wp_customize, 'vw_car_rental_slider_content_option', array(
        'type' => 'select',
        'label' => __('Slider Content Layouts','vw-car-rental'),
        'section' => 'vw_car_rental_slidersettings',
        'choices' => array(
            'Left' => get_template_directory_uri().'/assets/images/slider-content1.png',
            'Center' => get_template_directory_uri().'/assets/images/slider-content2.png',
            'Right' => get_template_directory_uri().'/assets/images/slider-content3.png',
    ))));

    //Slider excerpt
	$wp_customize->add_setting( 'vw_car_rental_slider_excerpt_number', array(
		'default'              => 30,
		'type'                 => 'theme_mod',
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'absint',
		'sanitize_js_callback' => 'absint',
	) );
	$wp_customize->add_control( 'vw_car_rental_slider_excerpt_number', array(
		'label'       => esc_html__( 'Slider Excerpt length','vw-car-rental' ),
		'section'     => 'vw_car_rental_slidersettings',
		'type'        => 'range',
		'settings'    => 'vw_car_rental_slider_excerpt_number',
		'input_attrs' => array(
			'step'             => 5,
			'min'              => 0,
			'max'              => 50,
		),
	) );

	//Opacity
	$wp_customize->add_setting('vw_car_rental_slider_opacity_color',array(
      'default'              => 0.5,
      'sanitize_callback' => 'vw_car_rental_sanitize_choices'
	));

	$wp_customize->add_control( 'vw_car_rental_slider_opacity_color', array(
	'label'       => esc_html__( 'Slider Image Opacity','vw-car-rental' ),
	'section'     => 'vw_car_rental_slidersettings',
	'type'        => 'select',
	'settings'    => 'vw_car_rental_slider_opacity_color',
	'choices' => array(
      '0' =>  esc_attr('0','vw-car-rental'),
      '0.1' =>  esc_attr('0.1','vw-car-rental'),
      '0.2' =>  esc_attr('0.2','vw-car-rental'),
      '0.3' =>  esc_attr('0.3','vw-car-rental'),
      '0.4' =>  esc_attr('0.4','vw-car-rental'),
      '0.5' =>  esc_attr('0.5','vw-car-rental'),
      '0.6' =>  esc_attr('0.6','vw-car-rental'),
      '0.7' =>  esc_attr('0.7','vw-car-rental'),
      '0.8' =>  esc_attr('0.8','vw-car-rental'),
      '0.9' =>  esc_attr('0.9','vw-car-rental')
	),
	));

	//Category
	$wp_customize->add_section( 'vw_car_rental_category_section' , array(
    	'title'      => __( 'Category Section', 'vw-car-rental' ),
		'priority'   => null,
		'panel' => 'vw_car_rental_panel_id'
	) );

	$categories = get_categories();
	$cat_post = array();
	$cat_post[]= 'select';
	$i = 0;	
	foreach($categories as $category){
		if($i==0){
			$default = $category->slug;
			$i++;
		}
		$cat_post[$category->slug] = $category->name;
	}

	$wp_customize->add_setting('vw_car_rental_category',array(
		'default'	=> 'select',
		'sanitize_callback' => 'vw_car_rental_sanitize_choices',
	));
	$wp_customize->add_control('vw_car_rental_category',array(
		'type'    => 'select',
		'choices' => $cat_post,
		'label' => __('Select Category to display post','vw-car-rental'),
		'description' => __('Image Size (50 x 45)','vw-car-rental'),
		'section' => 'vw_car_rental_category_section',
	));

	//Category excerpt
	$wp_customize->add_setting( 'vw_car_rental_category_excerpt_number', array(
		'default'              => 30,
		'type'                 => 'theme_mod',
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'absint',
		'sanitize_js_callback' => 'absint',
	) );
	$wp_customize->add_control( 'vw_car_rental_category_excerpt_number', array(
		'label'       => esc_html__( 'Category Excerpt length','vw-car-rental' ),
		'section'     => 'vw_car_rental_category_section',
		'type'        => 'range',
		'settings'    => 'vw_car_rental_category_excerpt_number',
		'input_attrs' => array(
			'step'             => 5,
			'min'              => 0,
			'max'              => 50,
		),
	) );

	//Services
	$wp_customize->add_section( 'vw_car_rental_service_section' , array(
    	'title'      => __( 'Services Section', 'vw-car-rental' ),
		'priority'   => null,
		'panel' => 'vw_car_rental_panel_id'
	) );

	$wp_customize->add_setting('vw_car_rental_section_title',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control('vw_car_rental_section_title',array(
		'label'	=> __('Section Title','vw-car-rental'),
		'input_attrs' => array(
            'placeholder' => __( 'Our Services', 'vw-car-rental' ),
        ),
		'section' => 'vw_car_rental_service_section',
		'setting' => 'vw_car_rental_section_title',
		'type' => 'text'
	));
	
	$categories = get_categories();
	$cat_post = array();
	$cat_post[]= 'select';
	$i = 0;	
	foreach($categories as $category){
		if($i==0){
			$default = $category->slug;
			$i++;
		}
		$cat_post[$category->slug] = $category->name;
	}

	$wp_customize->add_setting('vw_car_rental_services',array(
		'default'	=> 'select',
		'sanitize_callback' => 'vw_car_rental_sanitize_choices',
	));
	$wp_customize->add_control('vw_car_rental_services',array(
		'type'    => 'select',
		'choices' => $cat_post,
		'label' => __('Select Category to display services','vw-car-rental'),
		'description' => __('Image Size (50 x 45)','vw-car-rental'),
		'section' => 'vw_car_rental_service_section',
	));

	//Services excerpt
	$wp_customize->add_setting( 'vw_car_rental_services_excerpt_number', array(
		'default'              => 30,
		'type'                 => 'theme_mod',
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'absint',
		'sanitize_js_callback' => 'absint',
	) );
	$wp_customize->add_control( 'vw_car_rental_services_excerpt_number', array(
		'label'       => esc_html__( 'Service Excerpt length','vw-car-rental' ),
		'section'     => 'vw_car_rental_service_section',
		'type'        => 'range',
		'settings'    => 'vw_car_rental_services_excerpt_number',
		'input_attrs' => array(
			'step'             => 5,
			'min'              => 0,
			'max'              => 50,
		),
	) );

	//Blog Post
	$wp_customize->add_section('vw_car_rental_blog_post',array(
		'title'	=> __('Blog Post Settings','vw-car-rental'),
		'panel' => 'vw_car_rental_panel_id',
	));	

	$wp_customize->add_setting( 'vw_car_rental_toggle_postdate',array(
        'default' => 1,
        'transport' => 'refresh',
        'sanitize_callback' => 'vw_car_rental_switch_sanitization'
    ) );
    $wp_customize->add_control( new VW_Car_Rental_Toggle_Switch_Custom_Control( $wp_customize, 'vw_car_rental_toggle_postdate',array(
        'label' => esc_html__( 'Post Date','vw-car-rental' ),
        'section' => 'vw_car_rental_blog_post'
    )));

    $wp_customize->add_setting( 'vw_car_rental_toggle_author',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'vw_car_rental_switch_sanitization'
    ) );
    $wp_customize->add_control( new VW_Car_Rental_Toggle_Switch_Custom_Control( $wp_customize, 'vw_car_rental_toggle_author',array(
		'label' => esc_html__( 'Author','vw-car-rental' ),
		'section' => 'vw_car_rental_blog_post'
    )));

    $wp_customize->add_setting( 'vw_car_rental_toggle_comments',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'vw_car_rental_switch_sanitization'
    ) );
    $wp_customize->add_control( new VW_Car_Rental_Toggle_Switch_Custom_Control( $wp_customize, 'vw_car_rental_toggle_comments',array(
		'label' => esc_html__( 'Comments','vw-car-rental' ),
		'section' => 'vw_car_rental_blog_post'
    )));

    $wp_customize->add_setting( 'vw_car_rental_excerpt_number', array(
		'default'              => 30,
		'type'                 => 'theme_mod',
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'absint',
		'sanitize_js_callback' => 'absint',
	) );
	$wp_customize->add_control( 'vw_car_rental_excerpt_number', array(
		'label'       => esc_html__( 'Excerpt length','vw-car-rental' ),
		'section'     => 'vw_car_rental_blog_post',
		'type'        => 'range',
		'settings'    => 'vw_car_rental_excerpt_number',
		'input_attrs' => array(
			'step'             => 5,
			'min'              => 0,
			'max'              => 50,
		),
	) );

	//Content Craetion
	$wp_customize->add_section( 'vw_car_rental_content_section' , array(
    	'title' => __( 'Customize Home Page', 'vw-car-rental' ),
		'priority' => null,
		'panel' => 'vw_car_rental_panel_id'
	) );

	$wp_customize->add_setting('vw_car_rental_content_creation_main_control', array(
		'sanitize_callback' => 'esc_html',
	) );

	$homepage= get_option( 'page_on_front' );

	$wp_customize->add_control(	new VW_Car_Rental_Content_Creation( $wp_customize, 'vw_car_rental_content_creation_main_control', array(
		'options' => array(
			esc_html__( 'The edit button enables you to create homepage in a matter of minutes in just a few clicks. Just click on the edit option, add whatever elements you want to include in the homepage, save the changes and you are good to go', 'vw-car-rental' ),
		),
		'section' => 'vw_car_rental_content_section',
		'button_url'  => admin_url( 'post.php?post='.$homepage.'&action=edit'),
		'button_text' => esc_html__( 'Edit', 'vw-car-rental' ),
	) ) );

	//Footer Text
	$wp_customize->add_section('vw_car_rental_footer',array(
		'title'	=> __('Footer','vw-car-rental'),
		'panel' => 'vw_car_rental_panel_id',
	));	
	
	$wp_customize->add_setting('vw_car_rental_footer_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control('vw_car_rental_footer_text',array(
		'label'	=> __('Copyright Text','vw-car-rental'),
		'input_attrs' => array(
            'placeholder' => __( 'Copyright 2018, .....', 'vw-car-rental' ),
        ),
		'section'=> 'vw_car_rental_footer',
		'setting'=> 'vw_car_rental_footer_text',
		'type'=> 'text'
	));	

	$wp_customize->add_setting('vw_car_rental_scroll_top_alignment',array(
        'default' => __('Right','vw-car-rental'),
        'sanitize_callback' => 'vw_car_rental_sanitize_choices'
	));
	$wp_customize->add_control(new VW_Car_Rental_Image_Radio_Control($wp_customize, 'vw_car_rental_scroll_top_alignment', array(
        'type' => 'select',
        'label' => __('Scroll To Top','vw-car-rental'),
        'section' => 'vw_car_rental_footer',
        'settings' => 'vw_car_rental_scroll_top_alignment',
        'choices' => array(
            'Left' => get_template_directory_uri().'/assets/images/layout1.png',
            'Center' => get_template_directory_uri().'/assets/images/layout2.png',
            'Right' => get_template_directory_uri().'/assets/images/layout3.png'
    ))));
}

add_action( 'customize_register', 'vw_car_rental_customize_register' );

load_template( trailingslashit( get_template_directory() ) . '/inc/logo/logo-resizer.php' );

/**
 * Singleton class for handling the theme's customizer integration.
 *
 * @since  1.0.0
 * @access public
 */
final class VW_Car_Rental_Customize {

	/**
	 * Returns the instance.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return object
	 */
	public static function get_instance() {

		static $instance = null;

		if ( is_null( $instance ) ) {
			$instance = new self;
			$instance->setup_actions();
		}

		return $instance;
	}

	/**
	 * Constructor method.
	 *
	 * @since  1.0.0
	 * @access private
	 * @return void
	 */
	private function __construct() {}

	/**
	 * Sets up initial actions.
	 *
	 * @since  1.0.0
	 * @access private
	 * @return void
	 */
	private function setup_actions() {

		// Register panels, sections, settings, controls, and partials.
		add_action( 'customize_register', array( $this, 'sections' ) );

		// Register scripts and styles for the controls.
		add_action( 'customize_controls_enqueue_scripts', array( $this, 'enqueue_control_scripts' ), 0 );
	}

	/**
	 * Sets up the customizer sections.
	 *
	 * @since  1.0.0
	 * @access public
	 * @param  object  $manager
	 * @return void
	 */
	public function sections( $manager ) {

		// Load custom sections.
		load_template( trailingslashit( get_template_directory() ) . '/inc/section-pro.php' );

		// Register custom section types.
		$manager->register_section_type( 'VW_Car_Rental_Customize_Section_Pro' );

		// Register sections.
		$manager->add_section(new VW_Car_Rental_Customize_Section_Pro($manager,'example_1',array(
			'priority'   => 1,
			'title'    => esc_html__( 'VW CAR RENTAL', 'vw-car-rental' ),
			'pro_text' => esc_html__( 'UPGRADE PRO', 'vw-car-rental' ),
			'pro_url'  => esc_url('https://www.vwthemes.com/themes/car-rental-wordpress-theme/'),
		)));

		// Register sections.
		$manager->add_section(new VW_Car_Rental_Customize_Section_Pro($manager,'example_2',array(
			'priority'   => 1,
			'title'    => esc_html__( 'Documentation', 'vw-car-rental' ),
			'pro_text' => esc_html__( 'Docs', 'vw-car-rental' ),
			'pro_url'  => admin_url('themes.php?page=vw_car_rental_guide'),
		)));
	}

	/**
	 * Loads theme customizer CSS.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return void
	 */
	public function enqueue_control_scripts() {

		wp_enqueue_script( 'vw-car-rental-customize-controls', trailingslashit( get_template_directory_uri() ) . '/assets/js/customize-controls.js', array( 'customize-controls' ) );

		wp_enqueue_style( 'vw-car-rental-customize-controls', trailingslashit( get_template_directory_uri() ) . '/assets/css/customize-controls.css' );
	}
}

// Doing this customizer thang!
VW_Car_Rental_Customize::get_instance();